API docs for “spamfighter.txjsonrpc.web.jsonrpc.QueryFactory”

# Class s.t.w.j.QueryFactory(protocol.ClientFactory):

Part of spamfighter.txjsonrpc.web.jsonrpc View Source View In Hierarchy

Undocumented

Method | __init__ | Undocumented
Method | parseResponse | Undocumented
Method | clientConnectionLost | Undocumented
Method | badStatus | Undocumented

def __init__(self, path, host, method, *args, user=None, password=None): (source)
Undocumented
def parseResponse(self, contents): (source)
Undocumented
def clientConnectionLost(self, _, reason): (source)
Undocumented
def badStatus(self, status, message): (source)
Undocumented